@@ -4,4 +4,4 @@ from .services import *
 from .sync import *
 
 __all__ = ['InstanceStateIntEnum', 'StepTypeEnum', 'TimeoutMessagesEnum', 'PostgresDB', 'Native', 'RedisPWX',
-           'BaseService', 'EntitySync', 'PersistSync', 'InstanceStatusIntEnum']
+           'BaseService', 'EntitySync', 'PersistSync', 'InstanceStatusIntEnum', 'ORMSync']
